%define _libdir64 %{_prefix}/lib64

Summary: An HTTP and WebDAV client library
Name: neon
Version: 0.31.2
Release: 1
License: LGPL
Group: System Environment/Libraries
URL: http://www.webdav.org/neon/
Source0: https://notroj.github.io/neon//neon-%{version}.tar.gz
BuildRequires: expat-devel >= 2.2.9
BuildRequires: zlib-devel >= 1.2.11
BuildRequires: pkg-config, gettext
Requires: expat >= 2.2.9
Requires: zlib >= 1.2.11, gettext >= 0.19.8.1, libgcc >= 8.3.0

%description
neon is an HTTP and WebDAV client library, with a C interface;
providing a high-level interface to HTTP and WebDAV methods along
with a low-level interface for HTTP request handling.  neon
supports persistent connections, proxy servers, basic, digest and
Kerberos authentication, and has complete SSL support.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Development libraries and C header files for the neon library
Group: Development/Libraries
Requires: neon = %{version}-%{release}
#Requires: openssl-devel 
Requires: zlib-devel
Requires: expat-devel
Requires: pkg-config

%description devel
The development library for the C language HTTP and WebDAV client library.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "cc -q64" or "gcc -maix64".

%prep
%setup -q
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cp -rp 32bit/* 64bit/

%build
export RM="/usr/bin/rm -f"
export CONFIG_SHELL=/usr/bin/sh

# first build the 64-bit version
cd 64bit
export OBJECT_MODE=64
export CC="/opt/freeware/bin/gcc -maix64"
export CFLAGS="-I/opt/freeware/include -I/usr/include -maix64 -O2"
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_prefix}/man \
    --enable-shared --enable-static \
    --with-ssl=openssl \
    --with-expat \
    --libdir=%{_libdir64} 

gmake %{?_smp_mflags}

(gmake -k check || true)
/usr/sbin/slibclean

# now build the 32-bit version
cd ../32bit
export OBJECT_MODE=32
export CC="/opt/freeware/bin/gcc -maix32"
export CFLAGS="-I/opt/freeware/include -I/usr/include -maix32 -O2 -D_LARGE_FILES"
export LDFLAGS="-L/opt/freeware/lib -Wl,-bmaxdata:0x80000000 -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_prefix}/man \
    --enable-shared --enable-static \
    --with-ssl=openssl \
    --with-expat

gmake %{?_smp_mflags}

(gmake -k check || true)
/usr/sbin/slibclean


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
make DESTDIR=${RPM_BUILD_ROOT} install

cd ../32bit
export OBJECT_MODE=32
make DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.a ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}.so*

%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%doc 64bit/AUTHORS 64bit/BUGS 64bit/TODO 64bit/src/COPYING.LIB 64bit/NEWS 64bit/README.md 64bit/THANKS
%{_libdir}/*.a
%{_libdir64}/*.a

%files devel
%defattr(-,root,system)
%{_bindir}/*
%{_includedir}/*
%{_libdir}/pkgconfig/neon.pc
%{_libdir64}/pkgconfig/neon.pc
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_datadir}/*

%changelog
* Thu Aug 13 2020 Baanu Tumma <btumma15@in.ibm.com> - 0.31.2-1
- Update to 0.31.2
- no longer shipping files from /usr directory

* Sat Feb 10 2018 Ravi Hirekurabar <rhirekur@in.ibm.com> - 0.30.2-1
- Update to 0.30.2

* Thu Jul 04 2013 Gerard Visiedo <gerard.visiedo@bull.net> 0.29.6-2
- Update to 0.29.6 and build on Aix5.3

* Thu Jun 23 2011 Gerard Visiedo <gerard.visiedo@bull.net> 0.29.5
- Update to 0.29.5

* Thu Sep 30 2010 Jean Noel Cordenner <jean-noel.cordenner@bull.net> 0.29.3
- Initial port for AIX

